===================================
``psyclone.domain.common.psylayer``
===================================

.. automodule:: psyclone.domain.common.psylayer

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.domain.common.psylayer.psyloop

.. currentmodule:: psyclone.domain.common.psylayer


Classes
=======

- :py:class:`PSyLoop`:
  Node representing a psylayer loop within the PSyIR. It extends the PSyIR


.. autoclass:: PSyLoop
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: PSyLoop
      :parts: 1
